MetaInfo class final

Completed structure of rich information link preview metadata.

Although some fields are compulsory (for example, basic metadata in Open Graph Protocol), to ensure compatibility on various metadata structures, all fields are defined as optional which denote null if absent.

Annotations

Constructors

MetaInfo({String? title, Uri? url, Uri? secureUrl, String? description, String? siteName, List<AudioInfo> audios = const [], List<ImageInfo> images = const [], List<VideoInfo> videos = const []})
Create rich information link metadata.
factory

Properties

audios → List<AudioInfo>
An unmodifiabled collection of AudioInfo.
final
description → String?
Website's description.
final
hashCode → int
The hash code for this object.
no setterinherited
images → List<ImageInfo>
An unmodifiabled collection of ImageInfo.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secureUrl → Uri?
Link to resources using HTTPS.
final
siteName → String?
Name of website.
final
title → String?
Title of website.
final
url → Uri?
Link to resources.
final
videos → List<VideoInfo>
An unmodifiabled collection of VideoInfo.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

merge(MetaInfo primary, List<MetaInfo> fallbacks, {required MetaMergePreference preference}) → MetaInfo
Merge primary metadata with fallbacks with difference preference applied.