VideoInfo class final

Define metadata information for playing video in preview.

Annotations

Constructors

VideoInfo({Uri? url, Uri? secureUrl, String? type, double? width, double? height})
Create video metadata with provided resources.

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double?
Height of visual.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secureUrl → Uri?
Link to resources using HTTPS.
final
type → String?
MIME type of given media.
final
url → Uri?
Link to resources.
final
width → double?
Width of visual.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited